@@ -80,8 +80,15 @@ class WebhookTestingGateway(object):
             return self.__ideal_payment_complete_sample_xml(id)
         elif kind == WebhookNotification.Kind.IdealPaymentFailed:
             return self.__ideal_payment_failed_sample_xml(id)
+        # NEXT_MAJOR_VERSION remove GrantedPaymentInstrumentUpdate
         elif kind == WebhookNotification.Kind.GrantedPaymentInstrumentUpdate:
             return self.__granted_payment_instrument_update()
+        elif kind == WebhookNotification.Kind.GrantorUpdatedGrantedPaymentMethod:
+            return self.__granted_payment_instrument_update()
+        elif kind == WebhookNotification.Kind.RecipientUpdatedGrantedPaymentMethod:
+            return self.__granted_payment_instrument_update()
+        elif kind == WebhookNotification.Kind.LocalPaymentCompleted:
+            return self.__local_payment_completed()
         else:
             return self.__subscription_sample_xml(id)
 
@@ -619,3 +626,11 @@ class WebhookTestingGateway(object):
                 </updated-fields>
             </granted-payment-instrument-update>
             """
+
+    def __local_payment_completed(self):
+        return """
+            <local-payment>
+                <payment-id>a-payment-id</payment-id>
+                <payer-id>a-payer-id</payer-id>
+            </local-payment>
+            """
